@@ -29,9 +29,17 @@ class InvalidSignature(NotificationValidationError):
 
 def ebay_timestamp_string(datetime_obj):
     # convert python datetime obj to string representation used by eBay
-    # (truncate python's microseconds to eBay's milliseconds)
-    # eBay timestamps are UTC... the 'Z' timezone
-    return '%sZ' % datetime_obj.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3]
+    # appears to be a bug in suds - eBay's milliseconds are loaded into python datetime
+    # as microseconds so the datetime_obj we get from suds is not accurate to the data
+    return '%(year)d-%(month)d-%(day)dT%(hour)d:%(minute)d:%(second)d.%(millisecond)dZ' % {
+        'year': datetime_obj.year,
+        'month': datetime_obj.month,
+        'day': datetime_obj.day,
+        'hour': datetime_obj.hour,
+        'minute': datetime_obj.minute,
+        'second': datetime_obj.second,
+        'millisecond': datetime_obj.microsecond * 1000
+    }
 
 
 class NotificationHandler(object):
@@ -78,7 +86,7 @@ class NotificationHandler(object):
         
         floattime = time.mktime(message.Timestamp.timetuple())
         timestamp_str = ebay_timestamp_string(message.Timestamp)
-        log.info('%s -> %s', message.Timestamp, timestamp_str)
+        print '%s -> %s' % (message.Timestamp, timestamp_str)
         if not settings.DEBUG:
             # check timestamp is within 10 minutes of current time
             diff_seconds = math.fabs(time.time() - floattime)
