@@ -36,7 +36,7 @@ def get_notification_url(username=None):
 @csrf_exempt
 def notification(request, username=None):
     if settings.DEBUG:
-        with open('last_request.pkl', 'wb') as output:
+        with open(os.path.join(settings.PROJECT_ROOT, 'last_request.pkl'), 'wb') as output:
             meta = dict([(k,v) for k,v in request.META.items() if isinstance(v, basestring)])
             obj = {'META': meta, 'body': request.body}
             pickle.dump(obj, output)
